function plotsol(M, N, u)
%------------------------------------------------------------------------------------
% Plot the solution vector as a 2D array which has been converted to  a 1D array
% by following the "natural order" in numbering nodes.
%
% To match what was done with the Jacobi/Gauss-Seidel OMP heat diffusion problem,
% this needs to be called with mesh parameter N+1 instead of N.
%
% Two plots can be created: one using mesh(), and the other using plot3(). The
% latter is the methods used in showplate.m, so the pictures generated should be
% identical for the same inputs. They will differ in the x and y axis tick labels,
% since showplot.m uses integer indexing 0, 1, ..., N+1 for the axes, while this
% function uses x and y values ranging from 0 to 1.
%
% The plot3() version shows the boundary values in different colors, which may make
% it easier to see if the solution is correct.
%
% Added Tue 03 Apr 2018, 15:12:48 : you can also do a surfl() plot. For it, the
% shading is set to interpolate. It will create an extra large graphics window; see
% the figure command for it below.
%------------------------------------------------------------------------------------

    usemesh  = false; % set to true for a mesh plot
    useplot3 = false; % set to true for a plot3 plot
    usesurfl = true;  % set to true for a surf(l)plot

    if ~(usemesh || useplot3  || usesurfl )
        disp('Need to specify at least one plot in plotsol.m')
        return
    end

    [X, Y] = meshgrid(0:1:M, 0:1:N);
    X = X/M;
    Y = Y/N;

    G = zeros(M+1, N+1);

    for ix = 0:M
        G(ix+1, 1)   = BC(ix/M, 0); % Left hand boundary
        G(ix+1, N+1) = BC(ix/M, 1); % Right hand boundary
    end 

    for iy = 0:N
        G(1, iy+1)   = BC(0, iy/N); % Bottom boundary
        G(M+1, iy+1) = BC(1, iy/N); % Top boundary
    end

    % Interior nodes from the solver
    for iy = 1:N-1
        for ix = 1:M-1
            G(ix+1, iy+1) = u(ix+(iy-1)*(M-1));
        end
    end
    G = G';

    if usemesh
        figure
        mesh(X, Y, G)  % or could use meshc(X, Y, G) instead
        title('Computed Solution u(x,y)');
    end

    if useplot3
        If = find(X == 0);
        Il = find(X == 1);
        Jf = find(Y == 0);
        Jl = find(Y == 1);

        figure
        plot3(X, Y, G, 'b+', ...
            X(If), Y(If), G(If), 'c+', ...
            X(Il), Y(Il), G(Il), 'r+', ...
            X(Jf), Y(Jf), G(Jf), 'g*', ...
            X(Jl), Y(Jl), G(Jl), 'mo')
        title('Computed Solution u(x,y)');
    end

    if usesurfl
        pos = [0.1 0.1 0.7 0.7];
        fighandle = figure('Units', 'normalized', 'Position', pos);
        surfl(X, Y, G)
        shading interp
        % spinmap(15,1)
    end

return

